Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cell ¶
type Cell struct {
Id CellId `bson:"_id" json:"cellId"`
History []CellHistory `bson:"h" json:"history"`
}
Cell contains information for each cell on the Grid page. It includes both the cell's identifier and its history.
type CellHistory ¶
type CellHistory struct {
Id string `bson:"d" json:"id"`
Revision string `bson:"v" json:"revision"`
Status string `bson:"s" json:"status"`
StatusDetails apimodels.TaskEndDetail `bson:"e" json:"task_end_details"`
}
CellHistory holds historical data for each cell on the Grid page.
type Failure ¶
type Failure struct {
Id FailureId `bson:"_id" json:"identifier"`
Variants []VariantInfo `bson:"a" json:"variants"`
}
Failure contains data for a particular test failure - including the test's task display name, and the variants its failing on.
type VariantInfo ¶
type VariantInfo struct {
Name string `bson:"n" json:"name"`
TaskId string `bson:"i" json:"task_id"`
}
VariantInfo holds information for each variant a test fails on.
Click to show internal directories.
Click to hide internal directories.